# External document references
# Paths are relative to the haiv root
# These are loaded on wake along with work/ and home/ files

# Example:
# [[references]]
# path = "src/haiv_project/__assets__/roles/generalist.md"
