{# Template for user-level pyproject.toml created by hv users new #}
[project]
name = "haiv-user"
version = "0.1.0"
description = "User-level haiv commands and configuration"
requires-python = ">=3.12"
dependencies = [
    "haiv",
]

[build-system]
requires = ["hatchling"]
build-backend = "hatchling.build"

[tool.hatch.build.targets.wheel]
packages = ["src/haiv_user"]

[dependency-groups]
dev = [
    "pytest>=8.0",
]

[tool.pytest.ini_options]
testpaths = ["tests"]
pythonpath = ["src"]
